@@ -11,28 +11,31 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized once );
 
-our $VERSION = '1.878';
+our $VERSION = '1.880';
 
 use base 'MCE::Mutex';
-use Scalar::Util qw(weaken);
 use MCE::Util ();
+use Scalar::Util qw(looks_like_number weaken);
+use Time::HiRes 'alarm';
 
-my $tid = $INC{'threads.pm'} ? threads->tid() : 0;
+my $is_MSWin32 = ($^O eq 'MSWin32') ? 1 : 0;
+my $use_pipe = ($^O !~ /mswin|mingw|msys|cygwin/i && $] gt '5.010000');
+my $tid = $INC{'threads.pm'} ? threads->tid : 0;
 
 sub CLONE {
-    $tid = threads->tid() if $INC{'threads.pm'};
+    $tid = threads->tid if $INC{'threads.pm'};
 }
 
 sub DESTROY {
     my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, @_);
 
-    syswrite($obj->{_w_sock}, '0'), $obj->{$pid    } = 0 if $obj->{$pid    };
-    syswrite($obj->{_r_sock}, '0'), $obj->{$pid.'b'} = 0 if $obj->{$pid.'b'};
+    CORE::syswrite($obj->{_w_sock}, '0'), $obj->{$pid    } = 0 if $obj->{$pid    };
+    CORE::syswrite($obj->{_r_sock}, '0'), $obj->{$pid.'b'} = 0 if $obj->{$pid.'b'};
 
     if ( $obj->{_init_pid} eq $pid ) {
-        ($^O eq 'MSWin32' && $obj->{impl} eq 'Channel')
-            ? MCE::Util::_destroy_pipes($obj, qw(_w_sock _r_sock))
-            : MCE::Util::_destroy_socks($obj, qw(_w_sock _r_sock));
+        (!$use_pipe || $obj->{impl} eq 'Channel2')
+            ? MCE::Util::_destroy_socks($obj, qw(_w_sock _r_sock))
+            : MCE::Util::_destroy_pipes($obj, qw(_w_sock _r_sock));
     }
 
     return;
@@ -45,9 +48,9 @@ sub _destroy {
 
     # Called by { MCE, MCE::Child, and MCE::Hobo }::_exit
     for my $i ( 0 .. @mutex - 1 ) {
-        syswrite($mutex[$i]->{_w_sock}, '0'), $mutex[$i]->{$pid} = 0
+        CORE::syswrite($mutex[$i]->{_w_sock}, '0'), $mutex[$i]->{$pid} = 0
             if ( $mutex[$i]->{$pid} );
-        syswrite($mutex[$i]->{_r_sock}, '0'), $mutex[$i]->{$pid.'b'} = 0
+        CORE::syswrite($mutex[$i]->{_r_sock}, '0'), $mutex[$i]->{$pid.'b'} = 0
             if ( $mutex[$i]->{$pid.'b'} );
     }
 }
@@ -64,14 +67,13 @@ sub _save_for_global_cleanup {
 
 sub new {
     my ($class, %obj) = (@_, impl => 'Channel');
-    $obj{'_init_pid'} = $tid ? $$ .'.'. $tid : $$;
+    $obj{_init_pid} = $tid ? $$ .'.'. $tid : $$;
 
-    ($^O eq 'MSWin32')
+    $use_pipe
         ? MCE::Util::_pipe_pair(\%obj, qw(_r_sock _w_sock))
-        : MCE::Util::_sock_pair(\%obj, qw(_r_sock _w_sock), undef, 1);
-
-    syswrite $obj{_w_sock}, '0';
+        : MCE::Util::_sock_pair(\%obj, qw(_r_sock _w_sock));
 
+    CORE::syswrite($obj{_w_sock}, '0');
     bless \%obj, $class;
 
     if ( caller !~ /^MCE:?/ || caller(1) !~ /^MCE:?/ ) {
@@ -84,6 +86,7 @@ sub new {
 sub lock {
     my ($pid, $obj) = ($tid ? $$ .'.'. $tid : $$, shift);
 
+    MCE::Util::_sock_ready($obj->{_r_sock}) if $is_MSWin32;
     MCE::Util::_sysread($obj->{_r_sock}, my($b), 1), $obj->{ $pid } = 1
         unless $obj->{ $pid };
 
@@ -109,6 +112,7 @@ sub synchronize {
     return unless ref($code) eq 'CODE';
 
     # lock, run, unlock - inlined for performance
+    MCE::Util::_sock_ready($obj->{_r_sock}) if $is_MSWin32;
     MCE::Util::_sysread($obj->{_r_sock}, $b, 1), $obj->{ $pid } = 1
         unless $obj->{ $pid };
 
@@ -123,6 +127,32 @@ sub synchronize {
 
 *enter = \&synchronize;
 
+sub timedwait {
+    my ($obj, $timeout) = @_;
+
+    $timeout = 1 unless defined $timeout;
+    Carp::croak('MCE::Mutex::Channel: timedwait (timeout) is not valid')
+        if (!looks_like_number($timeout) || $timeout < 0);
+
+    $timeout = 0.0003 if $timeout < 0.0003;
+    local $@; my $ret = '';
+
+    eval {
+        local $SIG{ALRM} = sub { die "alarm clock restart\n" };
+        alarm $timeout unless $is_MSWin32;
+
+        die "alarm clock restart\n"
+            if $is_MSWin32 && MCE::Util::_sock_ready($obj->{_r_sock}, $timeout);
+
+        $obj->lock_exclusive, $ret = 1;
+        alarm 0 unless $is_MSWin32;
+    };
+
+    alarm 0 unless $is_MSWin32;
+
+    $ret;
+}
+
 1;
 
 __END__
@@ -139,7 +169,7 @@ MCE::Mutex::Channel - Mutex locking via a pipe or socket
 
 =head1 VERSION
 
-This document describes MCE::Mutex::Channel version 1.878
+This document describes MCE::Mutex::Channel version 1.880
 
 =head1 DESCRIPTION
 
