@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized numeric );
 
-our $VERSION = '1.878';
+our $VERSION = '1.880';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
@@ -28,6 +28,10 @@ BEGIN {
    $_zero_bytes = "\x00\x00\x00\x00";
 }
 
+sub CLONE {
+   %_sock_ready = ();
+}
+
 our $LF = "\012";  Internals::SvREADONLY($LF, 1);
 
 our @EXPORT_OK   = qw( $LF get_ncpu );
@@ -363,7 +367,6 @@ sub _nonblocking {
    if ($^O eq 'MSWin32') {
       # MSWin32 FIONBIO - from winsock2.h macro
       my $nonblocking = $_[1] ? "\x00\x00\x00\x01" : "\x00\x00\x00\x00";
-
       ioctl($_[0], 0x8004667e, unpack("I", pack('P', $nonblocking)));
    }
    else {
@@ -429,7 +432,7 @@ MCE::Util - Utility functions
 
 =head1 VERSION
 
-This document describes MCE::Util version 1.878
+This document describes MCE::Util version 1.880
 
 =head1 SYNOPSIS
 
